@@ -19,8 +19,8 @@ __author__ = "Orsiris de Jong"
 __copyright__ = "Copyright (C) 2021 Orsiris de Jong"
 __description__ = "Retrieve complete Windows Update installed updates list"
 __licence__ = "BSD 3 Clause"
-__version__ = "2.0.4"
-__build__ = "2021100801"
+__version__ = "2.0.5"
+__build__ = "2021100802"
 
 import re
 from win32com import client
@@ -137,9 +137,6 @@ def get_windows_updates_com(
             and int(entry.ResultCode in valid_status_codes)
         ):
             updates.append(update)
-        else:
-            print("invalud")
-            print(update)
 
     return updates
 
